Task: Ubuntu
=============
Description: Dialogs between an Ubuntu user and an expert trying to fix issue, we use the V2 version, which cleaned the data to some extent. From Lowe et al. '15. 

Link: https://arxiv.org/abs/1506.08909.

Tags: #Ubuntu, #All, #ChitChat

